@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright 2010-2017 The pygit2 contributors
+# Copyright 2010-2025 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -25,12 +23,5 @@
 # the Free Software Foundation, 51 Franklin Street, Fifth Floor,
 # Boston, MA 02110-1301, USA.
 
-# Import from the future
-from __future__ import absolute_import
-
 # Import from pygit2
-try:
-    from ._libgit2 import ffi, lib as C
-except ImportError:
-    from ._run import ffi, preamble, C_KEYWORDS
-    C = ffi.verify(preamble, **C_KEYWORDS)
+from ._libgit2 import ffi, lib as C  # noqa: F401
